@@ -12,7 +12,7 @@ let _HAVE_GET_CREDENTIALS_OPENBSD = false
 let _HAVE_GET_CREDENTIALS_FREEBSD = false
 let _HAVE_GETPEEREID = false
 let _HAVE_FDATASYNC = true
-let _HAVE_NETDB_REENTRANT = false
+let _HAVE_NETDB_REENTRANT = true
 let _HAVE_REENTRANT_HOSTENT = true
 let _HAVE_ST_MTIM_TV_NSEC = true
 let _HAVE_ST_MTIMESPEC_TV_NSEC = false
